readmet
=======

This module contains functions and objects for handling (mostly reading) less popular or vendor-specific data file formats used in meteorology and neighboring sciences.

Requirements:
-------------

    pip install numpy pandas

Installation:
-------------

    python3 setup.py install


Documentation: 
--------------
See <http://druee.gitlab-pages.uni-trier.de/python-readmet/>

